# setup设置发行属性
from distutils.core import setup

setup(
    name='lance_issue_mod_text',
    version='1.0',
    description='第一个对外发布项目，测试',
    author='Lance',
    author_email='377544418@qq.com',
    py_modules=['issue_mod.Salary']
)